starcluster.progressbar.RotatingMarker

Package starcluster :: Module progressbar :: Class RotatingMarker |
[hide private]
[frames] | no frames]

# Class RotatingMarker

source code

A rotating marker for filling the bar of progress.

Instance Methods | [hide private]
__init__(self, markers=`'``|/-\\``'`) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
update(self, pbar) Returns the string representing the widget. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, markers=`'``|/-\\``'`) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### update(self, pbar) | source code
Returns the string representing the widget. The parameter pbar is a reference to the calling ProgressBar, where one can access attributes of the class for knowing how the update must be made. At least this function must be overriden. Overrides: ProgressBarWidget.update (inherited documentation)